pub struct MdbxCursor<'txn, K: TransactionKind, T: Table> { /* private fields */ }Expand description
A cursor for navigating the entries within a table. Wraps the libmdbx cursor so that we only expose our own methods.