Module utils
nimiq_
database
1.2.2
Module utils
Module Items
Structs
In crate nimiq_
database
nimiq_database
Module
utils
Structs

Indexed
Value
A data type used in dup tables that have a subkey. It allows having tables that map from a main key to a subkey (
index
) to a value (
value
).