pub struct IndexedValue<I: Key, V: Value> {
pub index: I,
pub value: V,
}Expand description
A data type used in dup tables that have a subkey.
It allows having tables that map from a main key to a subkey (index) to a value (value).
The index/subkey type must have a fixed size declared in its AsDatabaseBytes implementation.
Otherwise, the code will panic at compile time.
Fields
index: IThe subkey or index.
value: VThe associated value.
Implementations