MdbxReadTransaction

Enum MdbxReadTransaction 

pub enum MdbxReadTransaction<'db> {
    Read(MdbxTransaction<'db, RO>),
    Write(MdbxTransaction<'db, RW>),
}
A proxy object that can be either a read or a write transaction. This is used to the outside to hide the transaction kind generic.

Variants



Read(MdbxTransaction<'db, RO>)



Write(MdbxTransaction<'db, RW>)