pub enum TransactionProxy<'db, 'txn>where
'db: 'txn,{
Read(&'txn MdbxReadTransaction<'db>),
OwnedRead(MdbxReadTransaction<'db>),
}Expand description
A proxy object that can be either a read or a write transaction. This can be used to hide the transaction kind generic.
Variants
Read(&'txn MdbxReadTransaction<'db>)
OwnedRead(MdbxReadTransaction<'db>)