pub struct DatabaseConfig {
pub max_tables: Option<u64>,
pub max_readers: Option<u32>,
pub no_rdahead: bool,
pub size: Option<Range<isize>>,
pub coalesce: bool,
pub growth_step: Option<isize>,
pub shrink_threshold: Option<isize>,
}Expand description
Database config options.
Fields
max_tables: Option<u64>The maximum number of tables that can be opened.
max_readers: Option<u32>The maximum number of reader slots.
no_rdahead: boolWhether to enable/disable readahead.
size: Option<Range<isize>>The minimum/maximum file size of the database. Default max size is 2TB.
coalesce: boolAims to coalesce a Garbage Collection items.
growth_step: Option<isize>The growth step by which the database file will be increased when lacking space.
shrink_threshold: Option<isize>The threshold of unused space, after which the database file will be shrunk.