pub trait WriteCursor<'txn, T: Table>: ReadCursor<'txn, T> {
// Required methods
fn put(&mut self, key: &T::Key, value: &T::Value);
fn append(&mut self, key: &T::Key, value: &T::Value);
fn remove(&mut self);
}Expand description
A cursor is used for navigating the entries within a table. The read-write version can also delete entries.
Closely follows libmdbx’s cursor API.
Required Methods
Sourcefn put(&mut self, key: &T::Key, value: &T::Value)
fn put(&mut self, key: &T::Key, value: &T::Value)
Puts a new entry into the database. The cursor will be positioned on the new entry.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.