IndexedValue

Struct IndexedValue 

pub struct IndexedValue<I: Key, V: Value> {
    pub index: I,
    pub value: V,
}
A data type used in dup tables that have a subkey. It allows having tables that map from a main key to a subkey (index) to a value (value).

The index/subkey type must have a fixed size declared in its AsDatabaseBytes implementation. Otherwise, the code will panic at compile time.

Fields

index: I

The subkey or index.

value: V

The associated value.

Implementations

Source

impl<I: Key, V: Value> IndexedValue<I, V>

pub fn new(index: I, value: V) -> Self

Create a new indexed value.